package org.jeecg.modules.cheerPrinter.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.cheerPrinter.entity.CheerPrinter;
import org.jeecg.modules.cheerPrinter.service.ICheerPrinterService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 打印机配置
 * @Author: jeecg-boot
 * @Date:   2024-10-06
 * @Version: V1.0
 */
@Api(tags="打印机配置")
@RestController
@RequestMapping("/cheerPrinter/cheerPrinter")
@Slf4j
public class CheerPrinterController extends JeecgController<CheerPrinter, ICheerPrinterService> {
	@Autowired
	private ICheerPrinterService cheerPrinterService;
	
	/**
	 * 分页列表查询
	 *
	 * @param cheerPrinter
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "打印机配置-分页列表查询")
	@ApiOperation(value="打印机配置-分页列表查询", notes="打印机配置-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CheerPrinter>> queryPageList(CheerPrinter cheerPrinter,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<CheerPrinter> queryWrapper = QueryGenerator.initQueryWrapper(cheerPrinter, req.getParameterMap());
		Page<CheerPrinter> page = new Page<CheerPrinter>(pageNo, pageSize);
		IPage<CheerPrinter> pageList = cheerPrinterService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param cheerPrinter
	 * @return
	 */
	@AutoLog(value = "打印机配置-添加")
	@ApiOperation(value="打印机配置-添加", notes="打印机配置-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CheerPrinter cheerPrinter) {
		cheerPrinterService.save(cheerPrinter);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param cheerPrinter
	 * @return
	 */
	@AutoLog(value = "打印机配置-编辑")
	@ApiOperation(value="打印机配置-编辑", notes="打印机配置-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CheerPrinter cheerPrinter) {
		cheerPrinterService.updateById(cheerPrinter);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "打印机配置-通过id删除")
	@ApiOperation(value="打印机配置-通过id删除", notes="打印机配置-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		cheerPrinterService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "打印机配置-批量删除")
	@ApiOperation(value="打印机配置-批量删除", notes="打印机配置-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.cheerPrinterService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "打印机配置-通过id查询")
	@ApiOperation(value="打印机配置-通过id查询", notes="打印机配置-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CheerPrinter> queryById(@RequestParam(name="id",required=true) String id) {
		CheerPrinter cheerPrinter = cheerPrinterService.getById(id);
		if(cheerPrinter==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(cheerPrinter);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param cheerPrinter
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CheerPrinter cheerPrinter) {
        return super.exportXls(request, cheerPrinter, CheerPrinter.class, "打印机配置");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, CheerPrinter.class);
    }

}
