package org.jeecg.modules.cheerShop.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.cheerShop.entity.CheerShop;
import org.jeecg.modules.cheerShop.service.ICheerShopService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 加油站管理
 * @Author: jeecg-boot
 * @Date:   2024-10-10
 * @Version: V1.0
 */
@Api(tags="加油站管理")
@RestController
@RequestMapping("/cheerShop/cheerShop")
@Slf4j
public class CheerShopController extends JeecgController<CheerShop, ICheerShopService> {
	@Autowired
	private ICheerShopService cheerShopService;
	
	/**
	 * 分页列表查询
	 *
	 * @param cheerShop
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "加油站管理-分页列表查询")
	@ApiOperation(value="加油站管理-分页列表查询", notes="加油站管理-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CheerShop>> queryPageList(CheerShop cheerShop,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<CheerShop> queryWrapper = QueryGenerator.initQueryWrapper(cheerShop, req.getParameterMap());
		Page<CheerShop> page = new Page<CheerShop>(pageNo, pageSize);
		IPage<CheerShop> pageList = cheerShopService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param cheerShop
	 * @return
	 */
	@AutoLog(value = "加油站管理-添加")
	@ApiOperation(value="加油站管理-添加", notes="加油站管理-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CheerShop cheerShop) {
		cheerShopService.save(cheerShop);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param cheerShop
	 * @return
	 */
	@AutoLog(value = "加油站管理-编辑")
	@ApiOperation(value="加油站管理-编辑", notes="加油站管理-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CheerShop cheerShop) {
		cheerShopService.updateById(cheerShop);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "加油站管理-通过id删除")
	@ApiOperation(value="加油站管理-通过id删除", notes="加油站管理-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		cheerShopService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "加油站管理-批量删除")
	@ApiOperation(value="加油站管理-批量删除", notes="加油站管理-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.cheerShopService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "加油站管理-通过id查询")
	@ApiOperation(value="加油站管理-通过id查询", notes="加油站管理-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CheerShop> queryById(@RequestParam(name="id",required=true) String id) {
		CheerShop cheerShop = cheerShopService.getById(id);
		if(cheerShop==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(cheerShop);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param cheerShop
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CheerShop cheerShop) {
        return super.exportXls(request, cheerShop, CheerShop.class, "加油站管理");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, CheerShop.class);
    }

}
